docpos

Attribute Macro docpos 

#[docpos]
the principal attribute inside this crate that lets us document function or struct arguments, but after them, not before Allows either #[docpos(struct)] (or ‘fn’, ‘enum’) literal syntax or just #[docpos] for autodetection